/*
 * This file is part of Generic Data Structures Library (GDSL).
 * Copyright (C) 1998-2001 Nicolas Darnis <ndarnis@free.fr>
 *
 * The GDSL library is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * The GDSL library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the GDSL library; see the file COPYING.
 * If not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 *
 * File: gdsl.h
 * $Revision: 1.4 $
 * $Date: 2002/02/21 09:55:51 $
 * $Author: ndarnis $
 * $Id: gdsl.h,v 1.4 2002/02/21 09:55:51 ndarnis Exp $
 */

#ifndef _GDSL_H_
#define _GDSL_H_

/*
 * This is the GDSL main header file.
 * Include it in your source code to be able to use all GDSL modules.
 */

#include "gdsl_types.h"
#include "gdsl_macros.h"

/* 
 * High-level modules: it is strongly suggested to use only the modules listed
 * in this file because other ones contains functions that will be modified in 
 * future.
 */
#include "gdsl_list.h"            /* lists */
#include "gdsl_stack.h"           /* stacks */
#include "gdsl_queue.h"           /* queues */
#include "gdsl_hash.h"            /* hash-tables */
#include "gdsl_2darray.h"         /* 2D arrays */
#include "gdsl_bstree.h"          /* binary search trees */
#include "gdsl_perm.h"            /* permutations */
#include "gdsl_rbtree.h"          /* red-black trees */
#include "gdsl_heap.h"            /* heaps */

/* 
 * Low-level modules: use them only if you know what you're doing.
 */
#include "_gdsl_list.h"           /* low-level lists */
#include "_gdsl_bintree.h"        /* low-level binary trees */
#include "_gdsl_bstree.h"         /* low-level binary search trees */
#include "_gdsl_mem.h"            /* memory management module */

#if defined (__cplusplus)
extern "C" {
#endif /* __cplusplus */

extern const char *
gdsl_get_version_string (void);

extern const char *
gdsl_get_version_number (void);

#ifdef __cplusplus
}
#endif/* __cplusplus */

#endif /* _GDSL_H_ */
