/*
 * This file is part of Generic Data Structures Library (GDSL).
 * Copyright (C) 1998-2001 Nicolas Darnis <ndarnis@free.fr>
 *
 * The GDSL library is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * The GDSL library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the GDSL library; see the file COPYING.
 * If not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 *
 * File: gdsl_heap.h
 * $Revision: 1.3 $
 * $Date: 2002/02/21 09:55:51 $
 * $Author: ndarnis $
 * $Id: gdsl_heap.h,v 1.3 2002/02/21 09:55:51 ndarnis Exp $
 */

#ifndef _GDSL_HEAP_H_
#define _GDSL_HEAP_H_

#include "gdsl_types.h"

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Sorts an array in place using a heap.
 * Sorts the array T in place using a heap. The function COMP_F is used to
 * compare T's elements and must be user-defined.
 * In case of success, returns 0.
 * In case of failure, returns -1;
 *
 * Complexity: O( N log( N ) )
 *
 * Requires: N == |T| & T != NULL & COMP_F != NULL
 */
extern int
gdsl_heap_sort (gdsl_element_t *T,                       /* Tab to be sorted */ 
		ulong N,                        /* Number of elements into T */
		gdsl_compare_func_t COMP_F          /* Comp. function to use */
		);

#ifdef __cplusplus
}
#endif

#endif /* _GDSL_HEAP_H_ */
